boofun.analysis.invariance
==========================

.. automodule:: boofun.analysis.invariance


   .. rubric:: Functions

   .. autosummary::

      bivariate_gaussian_cdf
      compute_test_function_expectation
      gaussian_cdf
      invariance_distance
      is_stablest_candidate
      majority_noise_stability
      max_cut_approximation_ratio
      multilinear_extension_gaussian_expectation
      noise_stability_deficit
      unique_games_hardness_bound

   .. rubric:: Classes

   .. autosummary::

      InvarianceAnalyzer
